==> seed7_05_20130704.tgz: seed7/src/match.h <==
/********************************************************************/
/*                                                                  */
/*  s7   Seed7 interpreter                                          */
/*  Copyright (C) 1990 - 2000  Thomas Mertes                        */
/*                                                                  */
/*  This program is free software; you can redistribute it and/or   */
/*  modify it under the terms of the GNU General Public License as  */
/*  published by the Free Software Foundation; either version 2 of  */
/*  the License, or (at your option) any later version.             */
/*                                                                  */
/*  This program is distributed in the hope that it will be useful, */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of  */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the   */
/*  GNU General Public License for more details.                    */
/*                                                                  */
/*  You should have received a copy of the GNU General Public       */
/*  License along with this program; if not, write to the           */
/*  Free Software Foundation, Inc., 51 Franklin Street,             */
/*  Fifth Floor, Boston, MA  02110-1301, USA.                       */
/*                                                                  */
/*  Module: Analyzer                                                */
/*  File: seed7/src/match.h                                         */
/*  Changes: 1995, 1999, 2000  Thomas Mertes                        */
/*  Content: Procedures to do static match on expressions.          */
/*                                                                  */
/********************************************************************/

void substitute_params (const_objecttype expr_object);
void update_owner (const_objecttype expr_object);
objecttype match_object (objecttype object);
objecttype match_expression (objecttype expr_object);
objecttype match_prog_expression (const_nodetype start_node,
    objecttype expr_object);

==> seed7_05_20240322.tgz: seed7/src/match.h <==
/********************************************************************/
/*                                                                  */
/*  s7   Seed7 interpreter                                          */
/*  Copyright (C) 1990 - 2000  Thomas Mertes                        */
/*                                                                  */
/*  This program is free software; you can redistribute it and/or   */
/*  modify it under the terms of the GNU General Public License as  */
/*  published by the Free Software Foundation; either version 2 of  */
/*  the License, or (at your option) any later version.             */
/*                                                                  */
/*  This program is distributed in the hope that it will be useful, */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of  */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the   */
/*  GNU General Public License for more details.                    */
/*                                                                  */
/*  You should have received a copy of the GNU General Public       */
/*  License along with this program; if not, write to the           */
/*  Free Software Foundation, Inc., 51 Franklin Street,             */
/*  Fifth Floor, Boston, MA  02110-1301, USA.                       */
/*                                                                  */
/*  Module: Analyzer                                                */
/*  File: seed7/src/match.h                                         */
/*  Changes: 1995, 1999, 2000  Thomas Mertes                        */
/*  Content: Functions to do static match on expressions.           */
/*                                                                  */
/********************************************************************/

void substitute_params (const_objectType expr_object);
void update_owner (const_objectType expr_object);
objectType match_object (objectType object);
objectType match_expression (objectType expr_object);
objectType match_prog_expression (const_nodeType start_node,
    objectType expr_object);
